"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[17420,58809,19069,4062,85757,14980],{85775:function(e,i,o){o.r(i);var s=o(62540),a=o(11444),t=(o(63696),o(37632)),l=o(65242),n=o(63739),c=o(46850),r=o(65369),p=o(4672),T={viewType:c.D.Movies,collectionType:r.X.Movies,isBtnShuffleEnabled:!0,itemType:[a.D.Movie]},v={viewType:c.D.Collections,collectionType:r.X.Movies,isBtnFilterEnabled:!1,isBtnNewCollectionEnabled:!0,isAlphabetPickerEnabled:!1,itemType:[a.D.BoxSet],noItemsMessage:"MessageNoCollectionsAvailable"},y={viewType:c.D.Favorites,collectionType:r.X.Movies,itemType:[a.D.Movie]},b={viewType:c.D.Trailers,itemType:[a.D.Trailer],noItemsMessage:"MessageNoTrailersFound"},d={0:T,1:{viewType:c.D.Suggestions,collectionType:r.X.Movies,sectionsView:p.Nc},2:b,3:y,4:v,5:{viewType:c.D.Genres,collectionType:r.X.Movies,itemType:[a.D.Movie]}};i.default=function(){var e=(0,t.A)(),i=e.libraryId,o=e.activeTab,a=d[o];return(0,s.jsx)(l.A,{id:"moviesPage",className:"mainAnimatedPage libraryPage backdropPage collectionEditorPage pageWithAbsoluteTabs withTabs",backDropType:"movie",children:(0,s.jsx)(n.A,{currentTab:a,parentId:i},"".concat(a.viewType," - ").concat(i))})}}}]);