"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[56376],{71609:function(e,t,a){a.r(t),a(44962),a(86584),a(78557),a(90076),a(83994),a(82367);var n=a(22696),o=a.n(n),i=(a(96244),a(8566)),r=a(5898),u=a(89100),l=a(41177);function c(){i.Ay.show();var e=this;return ApiClient.getNamedConfiguration(s).then((function(t){t.UserId=$("#selectUser",e).val()||null,t.ReleaseDateFormat=$("#selectReleaseDateFormat",e).val(),t.SaveImagePathsInNfo=e.querySelector("#chkSaveImagePaths").checked,t.EnablePathSubstitution=e.querySelector("#chkEnablePathSubstitution").checked,t.EnableExtraThumbsDuplication=e.querySelector("#chkEnableExtraThumbs").checked,ApiClient.updateNamedConfiguration(s,t).then((function(){var e;u.default.processServerConfigurationUpdateResult(),(e=[]).push(r.Ay.translate("MetadataSettingChangeHelp")),(0,l.A)({text:e.join("<br/><br/>")})}))})),!1}var s="xbmcmetadata";$(document).on("pageinit","#metadataNfoPage",(function(){$(".metadataNfoForm").off("submit",c).on("submit",c)})).on("pageshow","#metadataNfoPage",(function(){i.Ay.show();var e=this,t=ApiClient.getUsers(),a=ApiClient.getNamedConfiguration(s);Promise.all([t,a]).then((function(t){!function(e,t,a){var n='<option value="" selected="selected">'+r.Ay.translate("None")+"</option>";n+=a.map((function(e){return'<option value="'+e.Id+'">'+o()(e.Name)+"</option>"})).join(""),$("#selectUser",e).html(n).val(t.UserId||""),$("#selectReleaseDateFormat",e).val(t.ReleaseDateFormat),e.querySelector("#chkSaveImagePaths").checked=t.SaveImagePathsInNfo,e.querySelector("#chkEnablePathSubstitution").checked=t.EnablePathSubstitution,e.querySelector("#chkEnableExtraThumbs").checked=t.EnableExtraThumbsDuplication,i.Ay.hide()}(e,t[1],t[0])}))}))}}]);