"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[20966],{54340:function(e,t,n){n.r(t),n.d(t,{default:function(){return r}});var i=n(8566);function u(){i.Ay.show(),ApiClient.ajax({url:ApiClient.getUrl("Startup/Complete"),type:"POST"}).then((function(){i.Ay.hide(),window.location.href="index.html"}))}function r(e){e.querySelector(".btnWizardNext").addEventListener("click",u)}}}]);