"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[73730],{80927:function(t,e,i){i.r(e),i(67593),i(96054),i(96244);var n=i(8566),o=i(89100);function r(){n.Ay.show();var t=this;return ApiClient.getServerConfiguration().then((function(e){e.RemoteClientBitrateLimit=parseInt(1e6*parseFloat($("#txtRemoteClientBitrateLimit",t).val()||"0"),10),ApiClient.updateServerConfiguration(e).then(o.default.processServerConfigurationUpdateResult)})),!1}$(document).on("pageinit","#streamingSettingsPage",(function(){$(".streamingSettingsForm").off("submit",r).on("submit",r)})).on("pageshow","#streamingSettingsPage",(function(){n.Ay.show();var t=this;ApiClient.getServerConfiguration().then((function(e){!function(t,e){$("#txtRemoteClientBitrateLimit",t).val(e.RemoteClientBitrateLimit/1e6||""),n.Ay.hide()}(t,e)}))}))}}]);