"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[99994],{51673:function(l){l.exports=JSON.parse('{"AccessRestrictedTryAgainLater":"પ્રવેશ અત્યારે પ્રતિબંધિત છે. કૃપા કરીને પછી ફરીથી પ્રયત્ન કરજો.","Actor":"અભિનેતા","Album":"સંગ્રહિકા","Albums":"સંગ્રહો","AgeValue":"({0} વર્ષ જૂનું)","AirDate":"પ્રસાર તારીખ","AirPlay":"એરપ્લે","Aired":"પ્રસારિત","AlbumArtist":"સંગ્રાહિકા ના કલાકાર","Alerts":"સૂચના","All":"સર્વ","AllChannels":"બધા ચેનલો","AllComplexFormats":"બધા જટિલ પ્રારૂપમો (ASS, SSA, VobSub, PGS, SUB, IDX, ...)","AllEpisodes":"બધા એપિસોડ","AllLibraries":"બધા સંગ્રહો","AllowCollectionManagement":"આ વપરાશકર્તા ને સંગ્રહો નો સંચાલન કરવા ની અનુમતિ આપો","AllowContentWithTagsHelp":"ફક્ત તે મીડિયા બતાવો કે જેમાં ઓછામાં ઓછો એક ઉલ્લેખિત ટૅગ્સ માં થી એક હોય.","AllowSubtitleManagement":"આ વપરાશકર્તા ને ઉપશીર્ષકો નો સંપાદન કરવાની અનુમતિ આપો","AllowFfmpegThrottling":"થ્રોટલ ટ્રાન્સ્કોડ","Alternate":"અન્ય","AllLanguages":"બધી ભાષાઓ","AlternateDVD":"અન્ય DVD","AllowMediaConversion":"મીડિયા રૂપાંતરણની અનુમતિ આપો"}')}}]);