"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[56182],{84753:function(e,t,n){n.r(t),n.d(t,{default:function(){return l}}),n(44962),n(78557),n(90076),n(83994),n(82367);var i=n(8566),r=n(47629),a=(n(98959),n(10353),n(89100)),u=n(83375);function o(){var e=this;i.Ay.show();var t=(0,u.E)("id"),n=ApiClient.getJSON(ApiClient.getUrl("Devices/Info",{Id:t})),r=ApiClient.getJSON(ApiClient.getUrl("Devices/Options",{Id:t})).catch((function(){}));Promise.all([n,r]).then((function(t){!function(e,t,n){e.querySelector("#txtCustomName",e).value=(null==n?void 0:n.CustomName)||"",e.querySelector(".reportedName",e).innerText=t.Name||""}(e,t[0],t[1]),i.Ay.hide()}))}function s(e){var t,n;return t=r.Ay.parentWithClass(this,"page"),n=(0,u.E)("id"),ApiClient.ajax({url:ApiClient.getUrl("Devices/Options",{Id:n}),type:"POST",data:JSON.stringify({CustomName:t.querySelector("#txtCustomName").value}),contentType:"application/json"}).then(a.default.processServerConfigurationUpdateResult),e.preventDefault(),!1}function l(e){e.querySelector("form").addEventListener("submit",s),e.addEventListener("viewshow",o)}}}]);