#reactRoot{height:100%}@media (min-width:900px){.mainAnimatedPage{left:240px}}#myPreferencesMenuPage .adminSection,#myPreferencesMenuPage .lnkQuickConnectPreferences,#myPreferencesMenuPage .userSection{display:none!important}.homePage.libraryPage.withTabs,.libraryPage:not(.itemDetailPage):not(.withTabs){padding-top:3.25rem!important}.libraryPage.withTabs{padding-top:6.5rem!important}@media (min-width:1200px){.libraryPage.withTabs{padding-top:3.25rem!important}}.layout-mobile .itemBackdrop{margin-top:0!important}
