"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[64718],{44431:function(e,i,t){t.r(i),i.default='<div id="pluginsPage" data-role="page" class="page type-interior pluginConfigurationPage fullWidthContent" data-title="${TabPlugins}"> <div> <div class="content-primary"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${TabMyPlugins}</h2> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://jellyfin.org/docs/general/server/plugins/"> ${Help} </a> </div> <div class="inputContainer"> <input id="txtSearchPlugins" name="txtSearchPlugins" type="text" is="emby-input" label="${Search}"/> </div> <div class="installedPlugins"></div> </div> </div> </div> '}}]);