"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[72521],{72521:function(e,t,n){n.r(t),n.d(t,{default:function(){return c}}),n(29305),n(32733),n(78557),n(90076),n(95021),n(93062),n(97747);var i=n(34789),o=n(79754),r=n(46782),l=n(10838),a=n(5898),s=n(47629),c=(n(10353),n(15453),n(98959),(i.A.tv||i.A.xboxOne)&&window.confirm?function(e){"string"==typeof e&&(e={label:"",text:e});var t=(e.label||"").replaceAll("<br/>","\n"),n=prompt(t,e.text||"");return n?Promise.resolve(n):Promise.reject(n)}:function(e){return"string"==typeof e&&(e={title:"",text:e}),function(e){var t={removeOnClose:!0,scrollY:!1};r.A.tv&&(t.size="fullscreen");var n,i=o.default.createDialog(t);return i.classList.add("formDialog"),i.innerHTML=a.Ay.translateHtml('<div class="formDialogHeader"> <button is="paper-icon-button-light" class="btnCancel autoSize" tabindex="-1" title="${ButtonBack}"> <span class="material-icons arrow_back" aria-hidden="true"></span> </button> <h3 class="formDialogHeaderTitle"></h3> </div> <div class="formDialogContent smoothScrollY"> <div class="dialogContentInner dialog-content-centered" style="padding-top:2em"> <form> <div class="inputContainer"> <input is="emby-input" type="text" id="txtInput" label=""/> <div class="fieldDescription"></div> </div> <div class="formDialogFooter"> <button is="emby-button" type="submit" class="raised btnSubmit block formDialogFooterItem button-submit"> <span class="submitText"></span> </button> </div> </form> </div> </div> ',"core"),r.A.tv?l.default.centerFocus.on(i.querySelector(".formDialogContent"),!1):(i.querySelector(".dialogContentInner").classList.add("dialogContentInner-mini"),i.classList.add("dialog-fullscreen-lowres")),i.querySelector(".btnCancel").addEventListener("click",(function(){o.default.close(i)})),i.querySelector(".formDialogHeaderTitle").innerText=e.title||"",e.description?i.querySelector(".fieldDescription").innerText=e.description:i.querySelector(".fieldDescription").classList.add("hide"),function(e,t){var n=e.querySelector("#txtInput");n.label?n.label(t.label||""):n.setAttribute("label",t.label||""),n.value=t.value||""}(i,e),i.querySelector("form").addEventListener("submit",(function(e){return n=i.querySelector("#txtInput").value,e.preventDefault(),e.stopPropagation(),setTimeout((function(){o.default.close(i)}),300),!1})),i.querySelector(".submitText").innerText=e.confirmText||a.Ay.translate("ButtonOk"),i.style.minWidth="".concat(Math.min(400,s.Ay.getWindowSize().innerWidth-50),"px"),o.default.open(i).then((function(){return r.A.tv&&l.default.centerFocus.off(i.querySelector(".formDialogContent"),!1),n||Promise.reject()}))}(e)})}}]);