.skinHeader,
html {
    color: #f8f8fe;
    color: rgba(248, 248, 254, 0.973);
}

.wizardStartForm,
.ui-corner-all,
.ui-shadow {
    background-color: #303030;
}

.emby-collapsible-button {
    border-color: #383838;
    border-color: rgba(255, 255, 255, 0.135);
}

.skinHeader-withBackground {
    background: #000420;
    background: linear-gradient(to right, #000420 0%, #06256f 18%, #2b052b 38%, #2b052b 68%, #06256f 81%, #000420 100%);
}

.skinHeader.semiTransparent {
    backdrop-filter: none !important;
    background: linear-gradient(rgba(0, 0, 0, 0.6), rgba(0, 0, 0, 0));
    background-color: rgba(0, 0, 0, 0.3);
}

.layout-tv .skinHeader.semiTransparent {
    background: none;
}

.pageTitleWithDefaultLogo {
    background-image: url(../../assets/img/banner-light.png);
}

.layout-tv .pageTitleWithDefaultLogo {
    background-image: url(../../assets/img/icon-transparent.png);
}

.dialog,
.nowPlayingPlaylist,
.nowPlayingContextMenu,
html {
    background-color: #230c33;
}

.backgroundContainer {
    background: url(bg.jpg) center top no-repeat #030322;
    background-size: cover;
}

.backgroundContainer.withBackdrop {
    opacity: 0.86;
}

@media (orientation: portrait) {
    .backgroundContainer {
        background-position: 30% top;
    }
}

@media (hover: hover) and (pointer: fine) {
    .paper-icon-button-light:hover:not(:disabled) {
        color: rgb(12, 232, 214);
        background-color: rgba(0, 164, 220, 0.2);
    }
}

.paper-icon-button-light:active:not(:disabled) {
    color: rgb(12, 232, 214);
    background-color: rgba(0, 164, 220, 0.2);
}

.paper-icon-button-light.show-focus:focus {
    color: #ff77f1;
}

progress {
    border-radius: 0.4em;
}

progress::-webkit-progress-bar {
    border-radius: 0.4em;
}

progress::-moz-progress-bar {
    border-radius: 0.4em;
}

progress::-webkit-progress-value {
    border-radius: 0.4em;
}

.fab,
.raised {
    background: rgba(0, 0, 0, 0.5);
    color: rgba(255, 255, 255, 0.87);
}

.fab:focus,
.raised:focus {
    background: #ff77f1;
}

div[data-role=controlgroup] .controlGroupButton.ui-btn-active,
div[data-role=controlgroup] a.ui-btn-active {
    background: #55828b !important;
    color: #e1e5f2 !important;
}

.controlGroupButton,
a[data-role=button] {
    background: rgba(2, 43, 58, 0.521) !important;
}

#btnDeleteImage,
.submit,
.btnBrowse,
.mini,
.btnRefresh,
.btnManual,
.button-submit,
.viewTabButton,
.button-alt,
.btnOption {
    background: rgb(72, 195, 200);
    color: rgb(225, 229, 242);
}

#btnResetPassword,
.btnForgotPassword,
.btnCancel,
.button-cancel {
    background: rgba(0, 0, 0, 0.5);
    color: rgba(255, 255, 255, 0.87);
}

.alphaPickerButton {
    color: #999;
    color: rgba(255, 255, 255, 0.5);
    background-color: transparent;
}

#btnResetPassword:hover,
#btnRestart:hover,
#btnDeleteImage:hover,
#btnShutdown:hover,
.button-cancel:hover,
.fab:hover,
.raised:hover,
.alphaPickerButton:hover,
.submit:hover,
.btnBrowse:hover,
.mini:hover,
.btnRefresh:hover,
.button-submit:hover,
.viewTabButton:hover,
.button-alt:hover,
.btnOption:hover,
.btnManual:hover,
.block:hover {
    background: rgb(12, 232, 214);
    color: rgba(255, 255, 255, 0.87);
}

.button-submit:focus {
    background: #ff77f1;
}

.button-delete {
    background: rgb(247, 0, 0);
    color: rgba(255, 255, 255, 0.87);
}

.itemName {
    color: #f1f7ee;
}

.textareaLabel,
.sectionTitle,
.fieldDescription,
.checkboxLabel {
    color: #f1f7ee;
}

.checkboxLabel {
    color: inherit;
}

.selectLabel,
.checkboxLabel,
.checkboxListLabel,
.inputLabel,
.inputLabelUnfocused,
.paperListLabel,
.textareaLabelUnfocused {
    color: rgb(191, 219, 247);
}

.inputLabelFocused,
.selectLabelFocused,
.textareaLabelFocused {
    color: #ff77f1;
}

.checkboxOutline {
    border-color: currentColor;
}

.cardContent {
    border-radius: 0.8em;
}

.collapseContent,
.formDialogFooter:not(.formDialogFooter-clear),
.formDialogHeader:not(.formDialogHeader-clear),
.paperList,
.visualCardBox {
    background-color: rgba(0, 0, 0, 0.5);
    border-radius: 0.8em;
}

.layout-tv .formDialogFooter:not(.formDialogFooter-clear) {
    background-color: transparent;
    border-radius: 0;
}

.cardOverlayContainer {
    border-radius: 0.8em;
}

.blurhash-canvas {
    border-radius: 0.8em;
}

.defaultCardBackground1 {
    background-color: #9c20ab;
}

.defaultCardBackground2 {
    background-color: #d799de;
}

.defaultCardBackground3 {
    background-color: #412378;
}

.defaultCardBackground4 {
    background-color: #857b48;
}

.defaultCardBackground5 {
    background-color: #ab8820;
}

.cardText-secondary,
.fieldDescription,
.guide-programNameCaret,
.listItem .secondary,
.nowPlayingBarSecondaryText,
.programSecondaryTitle,
.secondaryText {
    color: #999;
    color: rgba(255, 255, 255, 0.5);
}

.actionsheetDivider {
    background: #444;
    background: rgba(255, 255, 255, 0.14);
}

.cardFooter-vibrant .cardText-secondary {
    color: inherit;
    opacity: 0.5;
}

.toast {
    background: #303030;
    color: #f8f8fe;
    color: rgba(255, 255, 255, 0.87);
}

.appfooter,
.playlistSectionButton {
    background: #06256f;
    color: #ccc;
    color: rgba(255, 255, 255, 0.78);
}

@supports (backdrop-filter:blur(10px)) or (-webkit-backdrop-filter:blur(10px)) {
    .appfooter {
        background: rgba(6, 37, 111, 0.7);
        backdrop-filter: blur(20px);
    }
}

.itemSelectionPanel {
    border: 1px solid #48c3c8;
}

.selectionCommandsPanel {
    background: #48c3c8;
    color: #f8f8fe;
}

.upNextDialog-countdownText {
    color: #48c3c8;
}

.alphaPickerButton-selected {
    color: #0ce8d6;
}

.alphaPickerButton-tv:focus {
    background: #ff77f1;
    color: #f8f8fe !important;
}

.detailRibbon {
    background: #000420;
    background: linear-gradient(to right, #000420 0%, #06256f 18%, #2b052b 38%, #2b052b 68%, #06256f 81%, #000420 100%);
}

.layout-tv .detailRibbon {
    background: none;
}

.noBackdropTransparency .detailPageSecondaryContainer {
    background: url(bg.jpg) center top no-repeat #030322;
    background-size: cover;
    background-attachment: fixed;
}

.detailTableBodyRow-shaded:nth-child(even) {
    background: #1c1c1c;
    background: rgba(30, 30, 30, 0.9);
}

.listItem-border {
    border-color: rgba(255, 255, 255, 0.1) !important;
}

.listItem:focus {
    background: rgba(0, 0, 0, 0.3);
}

.listItem:hover {
    background: #12122f;
}

.actionSheetMenuItem:hover {
    background-color: rgba(0, 0, 0, 0.5);
}

.progressring-spiner {
    border-color: #48c3c8;
}

.button-flat:hover {
    color: #48c3c8;
}

.button-link {
    color: #48c3c8;
}

.mediaInfoText {
    color: #f8f8fe;
    background: rgba(170, 170, 190, 0.2);
}

.emby-input,
.emby-textarea {
    color: inherit;
    background: rgba(0, 0, 0, 0.5);
    border: 0.16em solid transparent;
    border-radius: 0.2em;
}

.emby-input:focus,
.emby-textarea:focus {
    border-color: #ff77f1;
}

.emby-select-withcolor {
    color: inherit;
    background: rgba(0, 0, 0, 0.5);
    border: 0.07em solid transparent;
}

.emby-select-withcolor > option {
    color: inherit;
    background: #030322d7;
}

.emby-select-withcolor:focus {
    border-color: #ff77f1 !important;
}

.emby-select-tv-withcolor:focus {
    background-color: #ff77f1 !important;
    color: #fff !important;
}

.emby-checkbox:checked + span + .checkboxOutline {
    background-color: #030322;
    border: 0.14em solid rgb(72, 195, 200);
}

.emby-checkbox:checked + span + .checkboxOutline > .checkboxIcon-checked {
    color: rgb(12, 232, 214);
}

.emby-checkbox:focus + span + .checkboxOutline {
    border-color: #ff77f1;
}

.emby-checkbox:focus:not(:checked) + span + .checkboxOutline {
    border: 0.14em solid #ff77f1;
}

.itemProgressBarForeground {
    background-color: rgb(12, 232, 214);
}

.itemProgressBarForeground-recording {
    background-color: #cb272a;
}

.countIndicator,
.fullSyncIndicator,
.mediaSourceIndicator,
.playedIndicator {
    background: rgb(12, 232, 214);
}

.fullSyncIndicator {
    color: #fff;
}

.mainDrawer {
    color: #f8f8fe;
    background: rgba(0, 0, 0, 0.5);
}

.drawer-open {
    background-color: #030322;
}

.navMenuOption:hover {
    background: rgba(221, 221, 221, 0.068);
}

.navMenuOption-selected {
    background: #6f0765 !important;
    color: #f8f8fe;
}

.emby-button.show-focus:focus {
    background: #8ae9c1;
    color: #f8f8fe;
}

.mdl-radio.show-focus .mdl-radio__button:focus + .mdl-radio__circles svg .mdl-radio__outer-circle,
.mdl-radio.show-focus .mdl-radio__button:focus + .mdl-radio__circles svg .mdl-radio__inner-circle {
    color: #ff77f1;
}

.mdl-radio.show-focus .mdl-radio__button:focus + .mdl-radio__circles .mdl-radio__focus-circle {
    background: #00a4dc;
}

.emby-tab-button {
    color: #999;
}

.emby-tab-button-active {
    color: #f8f8fe;
}

.emby-tab-button.show-focus:focus {
    color: #ff77f1;
}

.emby-tab-button:hover {
    color: #ff77f1;
}

.channelPrograms,
.guide-channelHeaderCell,
.programCell {
    border-color: rgba(255, 255, 255, 0.05);
}

.programCell-sports {
    background: #3949ab !important;
}

.programCell-movie {
    background: #5e35b1 !important;
}

.programCell-kids {
    background: #039be5 !important;
}

.programCell-news {
    background: #43a047 !important;
}

.programCell-active {
    background: rgba(0, 0, 0, 0.4) !important;
}

.guide-channelHeaderCell:focus,
.programCell:focus {
    background-color: #48c3c8 !important;
    color: #fff !important;
}

.guide-programTextIcon {
    color: #1e1e1e;
    background: #555;
}

.guide-headerTimeslots {
    color: inherit;
}

.guide-date-tab-button {
    color: #555;
    color: rgba(255, 255, 255, 0.3);
}

.guide-date-tab-button.emby-tab-button-active,
.guide-date-tab-button:focus {
    color: #ff77f1;
}

.guide-date-tab-button.show-focus:focus {
    background-color: #48c3c8;
    color: #fff;
}

.infoBanner {
    color: #0e0f2d;
    background: #dbe6ff;
    padding: 1em;
    border-radius: 0.25em;
}

.ratingbutton-icon-withrating {
    color: #c33;
}

.downloadbutton-icon-complete,
.downloadbutton-icon-on {
    color: #4285f4;
}

.playstatebutton-icon-played {
    color: #c33;
}

.buttonActive {
    color: #00a4dc !important;
}

.personCard .cardScalable {
    border-radius: 50% !important;
    border: 1px solid rgb(255, 255, 255);
}

.cardBox:not(.visualCardBox) .cardPadder {
    background-color: rgba(0, 0, 0, 0.5);
    border-radius: 0.8em;
}

.cardPadder .cardImageIcon {
    color: rgba(0, 0, 0, 0.5);
}

.card:focus .cardBox.visualCardBox,
.card:focus .cardBox:not(.visualCardBox) .cardScalable {
    border-color: #ff77f1 !important;
}

.card.show-focus:not(.show-animation) .cardBox.visualCardBox,
.card.show-focus:not(.show-animation) .cardBox:not(.visualCardBox) .cardScalable {
    border-radius: 1.3em;
}

.layout-desktop,
.scrollY {
    scrollbar-width: thin;
    scrollbar-color: #888 rgba(59, 59, 59, 0.5);
}

::-webkit-scrollbar-track {
    box-shadow: inset 0 0 6px rgba(0, 0, 0, 0.3);
}

::-webkit-scrollbar-track-piece {
    background-color: rgba(59, 59, 59, 0.5);
}

.layout-desktop ::-webkit-scrollbar,
.layout-tv ::-webkit-scrollbar {
    width: 0.4em;
    height: 1em;
}

::-webkit-scrollbar-thumb:horizontal,
::-webkit-scrollbar-thumb:vertical {
    border-radius: 2px;
    background: center no-repeat #888;
}

.timeslotHeaders-desktop::-webkit-scrollbar {
    height: 0.7em;
}

.mediaInfoOfficialRating {
    border: 0.09em solid #583fa0;
    background-color: #dbe6ff;
    color: #0e0f2d;
}

.metadataSidebarIcon {
    color: #dbe6ff;
}

.personCard .overflowPortraitCard {
    width: 40vw;
}

.personCard .coveredImage {
    clip-path: circle(50% at 50% 50%);
}

.personCard .cardOverlayContainer {
    clip-path: circle(50% at 50% 50%);
}

.personCard .cardOverlayButton-br {
    right: 20%;
}

.personCard .cardPadder-overflowPortrait,
.personCard .cardPadder-portrait {
    padding-bottom: 100%;
    contain: strict;
    border-radius: 50% !important;
}
