"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[16949],{7274:function(e,t,o){o.r(t),o(96244);var n=o(8566),i=o(89100);function u(){n.Ay.show();var e=this;return ApiClient.getServerConfiguration().then((function(t){t.MinResumePct=$("#txtMinResumePct",e).val(),t.MaxResumePct=$("#txtMaxResumePct",e).val(),t.MinAudiobookResume=$("#txtMinAudiobookResume",e).val(),t.MaxAudiobookResume=$("#txtMaxAudiobookResume",e).val(),t.MinResumeDurationSeconds=$("#txtMinResumeDuration",e).val(),ApiClient.updateServerConfiguration(t).then(i.default.processServerConfigurationUpdateResult)})),!1}$(document).on("pageinit","#playbackConfigurationPage",(function(){$(".playbackConfigurationForm").off("submit",u).on("submit",u)})).on("pageshow","#playbackConfigurationPage",(function(){n.Ay.show();var e=this;ApiClient.getServerConfiguration().then((function(t){!function(e,t){$("#txtMinResumePct",e).val(t.MinResumePct),$("#txtMaxResumePct",e).val(t.MaxResumePct),$("#txtMinAudiobookResume",e).val(t.MinAudiobookResume),$("#txtMaxAudiobookResume",e).val(t.MaxAudiobookResume),$("#txtMinResumeDuration",e).val(t.MinResumeDurationSeconds),n.Ay.hide()}(e,t)}))}))}}]);