"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[90767],{96862:function(e,a,t){t.r(a),a.default='<div id="metadataImagesConfigurationPage" data-role="page" class="page type-interior metadataConfigurationPage" data-title="${LabelMetadata}"> <div> <div class="content-primary"> <form class="metadataImagesConfigurationForm"> <div class="verticalSection"> <h2 style="margin-top:0">${HeaderPreferredMetadataLanguage}</h2> <p style="margin:1.5em 0">${DefaultMetadataLangaugeDescription}</p> <div class="selectContainer"> <select is="emby-select" id="selectLanguage" required="required" label="${LabelLanguage}"></select> </div> <div class="selectContainer"> <select is="emby-select" id="selectCountry" required="required" label="${LabelCountry}"></select> </div> </div> <div class="verticalSection"> <h2>${HeaderDummyChapter}</h2> <div class="inputContainer"> <input is="emby-input" type="number" id="valDummyChapterDuration" label="${LabelDummyChapterDuration}" min="0"> <div class="fieldDescription">${LabelDummyChapterDurationHelp}</div> </div> <div class="selectContainer"> <select is="emby-select" id="txtChapterImageResolution" label="${LabelChapterImageResolution}"></select> <div class="fieldDescription"> <div>${LabelChapterImageResolutionHelp}</div> </div> </div> </div> <br/> <div> <button is="emby-button" type="submit" class="raised button-submit block"><span>${Save}</span></button> </div> </form> </div> </div> </div> '}}]);