(self.webpackChunk=self.webpackChunk||[]).push([[53402,33188],{24999:function(e,t,o){"use strict";o(36947);var r=o(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=r(o(56974)),u=["nedeľu","pondelok","utorok","stredu","štvrtok","piatok","sobotu"];function a(e){return 4===e?"'vo' eeee 'o' p":"'v "+u[e]+" o' p"}var s={lastWeek:function(e,t,o){var r=e.getUTCDay();return(0,n.default)(e,t,o)?a(r):function(e){var t=u[e];switch(e){case 0:case 3:case 6:return"'minulú "+t+" o' p";default:return"'minulý' eeee 'o' p"}}(r)},yesterday:"'včera o' p",today:"'dnes o' p",tomorrow:"'zajtra o' p",nextWeek:function(e,t,o){var r=e.getUTCDay();return(0,n.default)(e,t,o)?a(r):function(e){var t=u[e];switch(e){case 0:case 4:case 6:return"'budúcu "+t+" o' p";default:return"'budúci' eeee 'o' p"}}(r)},other:"P"};t.default=function(e,t,o,r){var n=s[e];return"function"==typeof n?n(t,o,r):n},e.exports=t.default},33188:function(e,t,o){"use strict";o(36947),o(78557),o(73687);var r=o(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e){(0,u.default)(1,arguments);var t=Object.prototype.toString.call(e);return e instanceof Date||"object"===(0,n.default)(e)&&"[object Date]"===t?new Date(e.getTime()):"number"==typeof e||"[object Number]"===t?new Date(e):("string"!=typeof e&&"[object String]"!==t||"undefined"==typeof console||(console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments"),console.warn((new Error).stack)),new Date(NaN))};var n=r(o(10564)),u=r(o(23058));e.exports=t.default},10564:function(e){function t(o){return e.exports=t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e.exports.__esModule=!0,e.exports.default=e.exports,t(o)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports}}]);