"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[70163],{1766:function(e,i,s){s.r(i),i.default='<div id="logPage" data-role="page" class="page type-interior" data-title="${TabLogs}"> <div> <div class="content-primary"> <form class="logsForm"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${TabLogs}</h2> </div> </div> <div class="verticalSection"> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkSlowResponseWarning"/> <span>${LabelSlowResponseEnabled}</span> </label> </div> <div class="inputContainer"> <input is="emby-input" type="number" id="txtSlowResponseWarning" label="${LabelSlowResponseTime}"/> </div> </div> <br/> <div> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </div> </form> <div class="serverLogs readOnlyContent"> </div> </div> </div> </div> '}}]);