"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[63549],{73053:function(e,t,o){o.r(t),o.d(t,{default:function(){return u}}),o(44962),o(78557),o(90076),o(83994),o(82367);var r=o(46782),c=o(50764),n=o(5898),l=o(90381),a=o(44797);function u(e){function t(t){return l.A.enableGamepad(e.querySelector(".chkEnableGamepad").checked),l.A.enableSmoothScroll(e.querySelector(".chkSmoothScroll").checked),(0,c.A)(n.Ay.translate("SettingsSaved")),a.A.trigger(e,"saved"),null==t||t.preventDefault(),!1}e.addEventListener("viewshow",(function(){e.querySelector(".smoothScrollContainer").classList.toggle("hide",!r.A.tv),e.querySelector(".chkEnableGamepad").checked=l.A.enableGamepad(),e.querySelector(".chkSmoothScroll").checked=l.A.enableSmoothScroll(),e.querySelector("form").addEventListener("submit",t),e.querySelector(".btnSave").classList.remove("hide"),Promise.resolve().then(o.bind(o,84069)).then((function(t){t.default.autoFocus(e)}))}))}}}]);