"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[70118],{7780:function(t,e,r){r.r(e),r.d(e,{default:function(){return l}}),r(29305),r(32733),r(84701),r(81678),r(44962),r(4754),r(94),r(36947),r(78557),r(90076),r(83994),r(82367);var n=r(86191),o=r(38783);function i(t){return i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},i(t)}function u(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(t,a(n.key),n)}}function a(t){var e=function(t,e){if("object"!=i(t)||!t)return t;var r=t[Symbol.toPrimitive];if(void 0!==r){var n=r.call(t,"string");if("object"!=i(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(t)}(t);return"symbol"==i(e)?e:e+""}var l=function(){return t=function t(){!function(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}(this,t),this.name="Photo Player",this.type=o.Q.MediaPlayer,this.id="photoplayer",this.priority=1},(e=[{key:"play",value:function(t){return new Promise((function(e){Promise.all([r.e(27884),r.e(77293)]).then(r.bind(r,27884)).then((function(r){var o=r.default,i=t.startIndex||0;n.A.currentApiClient().getCurrentUser().then((function(r){new o({showTitle:!1,cover:!1,items:t.items,startIndex:i,interval:11e3,interactive:!0,autoplay:t.autoplay||t.shuffle,user:r}).show(),e()}))}))}))}},{key:"canPlayMediaType",value:function(t){return"photo"===(t||"").toLowerCase()}}])&&u(t.prototype,e),Object.defineProperty(t,"prototype",{writable:!1}),t;var t,e}()}}]);