"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[27521],{37922:function(e){e.exports=JSON.parse('{"HeaderContinueWatching":"Үргэлжлүүлэн үзэх","Songs":"Дуунууд","Playlists":"Тоглуулах жагсаалт","Movies":"Кино","Genres":"Төрөл зүйл","Favorites":"Дуртай","Collections":"Багц","Artists":"Зураачуд","ButtonCancel":"Цуцлах","Artist":"Жүжигчин","Album":"Цомог","RecommendationBecauseYouWatched":"Та үзсэн болохоор {0}","InstantMix":"Шуурхай холимог","HeaderInstantMix":"Шуурхай холимог","OptionCriticRating":"Шүүмжлэгчдийн үнэлгээ","LabelCriticRating":"Шүүмжлэгчдийн үнэлгээ","CriticRating":"Шүүмжлэгчдийн үнэлгээ","OptionDateAdded":"Өдөр нэмэх","LabelDateAdded":"Өдөр нэмэх","DateAdded":"Өдөр нэмэх","MarkPlayed":"Тоглосон гэж тэмдэглэсэн","RecommendationDirectedBy":"Найруулсан {0}","RecordingCancelled":"Бичлэгийг цуцаллаа.","RecordSeries":"Цувралыг бичих","CancelSeries":"Цувралыг цуцлах","HeaderPlayAll":"Бүгдийг тоглуулах","HeaderOnNow":"Одоо асаах","NextUp":"Дараах","ContinueWatching":"Үргэлжлүүлэн үзэх","TypeOptionPluralEpisode":"Бүлгүүд","Episodes":"Бүлгүүд","Filters":"Шүүлтүүрүүд","Filter":"Шүүлтүүр","Name":"Нэр","LabelName":"Нэр","Never":"Боломжгүй","BirthDateValue":"Эхэлсэн: {0}","DashboardVersionNumber":"Хувилбар: {0}","LabelVersion":"Хувилбар","No":"Үгүй","Yes":"Тийм","ButtonTrailer":"Трейлер","TypeOptionPluralVideo":"Видеонууд","HeaderVideos":"Видеонууд","People":"Хүмүүс","Watched":"Үзсэн","TabUpcoming":"Дээшээ ирж байна","TypeOptionPluralSeason":"Үе","HeaderSeasons":"Үе","Series":"Цуврал","OptionSpecialEpisode":"Онцгой","CancelRecording":"Бичлэгийг цуцлах","Recordings":"Бичлэгүүд","Record":"Бичлэг","LabelRecord":"Бичлэг","ButtonTogglePlaylist":"Тоглуулах жагсаалт","ButtonSyncPlay":"SyncPlay","TabOther":"Бусад","Other":"Бусад","TypeOptionPluralMovie":"Кино","TabLatest":"Сүүлийн үеийн","Search":"Хайх","General":"Ерөнхий","Settings":"Тохиргоо","TitlePlayback":"Тоглуулах","HeaderSyncPlayPlaybackSettings":"Тоглуулах","MessageSyncPlayDisabled":"SyncPlay идэвхгүй.","None":"Байхгүй","LabelChromecastVersion":"Chromecast Хувилбар","HeaderCancelRecording":"Бичлэгийг цуцлах","Books":"Номууд","TypeOptionPluralBook":"Номууд","TV":"ТВ-ийн багц","Tuesday":"Мягмар гараг","Thursday":"Пүрэв гараг","Sunday":"Ням гараг","Season":"Үе","Saturday":"Бямба гариг","Play":"Тоглуулах","OptionProtocolHttp":"HTTP","OptionIsSD":"SD","OptionIsHD":"HD","OptionDvd":"DVD","Movie":"Кино","Monday":"Даваа","LabelPlaylist":"Тоглуулах жагсаалт","LabelCollection":"Багц","LabelAlbum":"Цомог","Genre":"Төрөл зүйл","Favorite":"Дуртай","DisablePlugin":"Идэвхгүй болгох","Bwdif":"BWDIF","OptionBluray":"BD","Option3D":"3D","Albums":"Цомгууд","Mobile":"Үүрэн","Desktop":"Компьютер","Absolute":"Бүрэн","AccessRestrictedTryAgainLater":"Одоогоор хандалт хязгаарлагдмал байна. Дараа дахин оролдож үзнэ үү.","Actor":"Жүжигчин","Add":"Нэмэх","AddedOnValue":"Нэмсэн"}')}}]);