"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[49803],{9383:function(n,o,t){var c;t.r(o),t.d(o,{AutoScroll:function(){return c}}),function(n){n[n.NoScroll=0]="NoScroll",n[n.Smooth=1]="Smooth",n[n.Instant=2]="Instant"}(c||(c={}))}}]);