"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[73567,58809,19069,4062,85757,14980],{86548:function(e,i,a){a.r(i);var n=a(62540),s=(a(63696),a(37632)),t=a(65242),r=a(63739),l=a(46850),c=a(4672),d={viewType:l.D.SeriesTimers,isPaginationEnabled:!1,isBtnFilterEnabled:!1,isBtnGridListEnabled:!1,isBtnSortEnabled:!1,isAlphabetPickerEnabled:!1},b={viewType:l.D.Schedule,sectionsView:c.jB},o={viewType:l.D.Recordings,sectionsView:c.wd},p={viewType:l.D.Channels,isBtnGridListEnabled:!1,isBtnSortEnabled:!1,isAlphabetPickerEnabled:!1},w={0:{viewType:l.D.Programs,sectionsView:c.qb},1:{viewType:l.D.Guide},2:p,3:o,4:b,5:d};i.default=function(){var e=(0,s.A)(),i=e.libraryId,a=e.activeTab,l=w[a];return(0,n.jsx)(t.A,{id:"liveTvPage",className:"mainAnimatedPage libraryPage collectionEditorPage pageWithAbsoluteTabs withTabs",children:(0,n.jsx)(r.A,{currentTab:l,parentId:i},"".concat(l.viewType," - ").concat(i))})}}}]);