"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[47588],{1161:function(n,t,r){r.d(t,{Q3:function(){return i}}),r(29305),r(32733),r(51770),r(84701),r(81678),r(2623),r(24776),r(14382),r(69892),r(84734),r(44962),r(87324),r(89336),r(4754),r(10849),r(58551),r(70389),r(94),r(33087),r(36947),r(36457),r(88908),r(26437),r(83810),r(52697),r(78557),r(96054),r(90076),r(95021),r(73687),r(83994),r(23630),r(82367);var e=r(63696),u=r(28601);function c(n,t){(null==t||t>n.length)&&(t=n.length);for(var r=0,e=Array(t);r<t;r++)e[r]=n[r];return e}function o(n){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:500,r=arguments.length>2?arguments[2]:void 0,c=(0,e.useRef)();!function(n){var t=(0,e.useRef)(n);t.current=n,(0,e.useEffect)((function(){return function(){t.current()}}),[])}((function(){c.current&&c.current.cancel()}));var o=(0,e.useMemo)((function(){var e=u(n,t,r),o=function(){return e.apply(void 0,arguments)};return o.cancel=function(){e.cancel()},o.isPending=function(){return!!c.current},o.flush=function(){return e.flush()},o}),[n,t,r]);return(0,e.useEffect)((function(){c.current=u(n,t,r)}),[n,t,r]),o}function i(n,t,r){var u,i,f,l=null!==(u=null==r?void 0:r.equalityFn)&&void 0!==u?u:function(n,t){return n===t},a=n instanceof Function?n():n,s=(i=(0,e.useState)(a),f=2,function(n){if(Array.isArray(n))return n}(i)||function(n,t){var r=null==n?null:"undefined"!=typeof Symbol&&n[Symbol.iterator]||n["@@iterator"];if(null!=r){var e,u,c,o,i=[],f=!0,l=!1;try{if(c=(r=r.call(n)).next,0===t){if(Object(r)!==r)return;f=!1}else for(;!(f=(e=c.call(r)).done)&&(i.push(e.value),i.length!==t);f=!0);}catch(n){l=!0,u=n}finally{try{if(!f&&null!=r.return&&(o=r.return(),Object(o)!==o))return}finally{if(l)throw u}}return i}}(i,f)||function(n,t){if(n){if("string"==typeof n)return c(n,t);var r={}.toString.call(n).slice(8,-1);return"Object"===r&&n.constructor&&(r=n.constructor.name),"Map"===r||"Set"===r?Array.from(n):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?c(n,t):void 0}}(i,f)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()),y=s[0],d=s[1],v=(0,e.useRef)(a),h=o(d,t,r);return l(v.current,a)||(h(a),v.current=a),[y,h]}"undefined"!=typeof window?e.useLayoutEffect:e.useEffect}}]);