"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[46326],{69751:function(e,t,s){s.r(t),t.default='<div id="repositories" data-role="page" class="page type-interior fullWidthContent" data-title="${TabRepositories}"> <div> <div class="content-primary"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${TabRepositories}</h2> <button is="emby-button" type="button" class="fab btnNewRepository submit" style="margin-left:1em" title="${Add}"> <span class="material-icons add" aria-hidden="true"></span> </button> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://jellyfin.org/docs/general/server/plugins/#repositories"> ${Help} </a> </div> <div id="repositories"></div> <div id="none" class="noItemsMessage centerMessage hide"> <h1>${MessageNoRepositories}</h1> <p>${MessageAddRepository}</p> </div> </div> </div> </div> '}}]);