"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[44119,37658],{37658:function(e,t,d){d(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e){return function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},d=t.width?String(t.width):e.defaultWidth;return e.formats[d]||e.formats[e.defaultWidth]}},e.exports=t.default},44119:function(e,t,d){d(36947);var l=d(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u=l(d(37658)),a={date:(0,u.default)({formats:{full:"EEEE, d 'de' MMMM 'de' y",long:"d 'de' MMMM 'de' y",medium:"d MMM y",short:"dd/MM/y"},defaultWidth:"full"}),time:(0,u.default)({formats:{full:"HH:mm:ss zzzz",long:"HH:mm:ss z",medium:"HH:mm:ss",short:"HH:mm"},defaultWidth:"full"}),dateTime:(0,u.default)({formats:{full:"{{date}} 'a las' {{time}}",long:"{{date}} 'a las' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})};t.default=a,e.exports=t.default}}]);