"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[23488],{1338:function(e,t,a){a.r(t),a.d(t,{default:function(){return o}});var r=a(5898),n=a(89100);function s(e){if("ContactAdmin"!=e.Action)if("InNetworkRequired"!=e.Action){if("PinCode"==e.Action){var t=r.Ay.translate("MessageForgotPasswordFileCreated");t+="<br/>",t+="<br/>",t+="Enter PIN here to finish Password Reset<br/>",t+="<br/>",t+=e.PinFile,t+="<br/>",n.default.alert({message:t,title:r.Ay.translate("ButtonForgotPassword"),callback:function(){n.default.navigate("forgotpasswordpin.html")}})}}else n.default.alert({message:r.Ay.translate("MessageForgotPasswordInNetworkRequired"),title:r.Ay.translate("ButtonForgotPassword")});else n.default.alert({message:r.Ay.translate("MessageContactAdminToResetPassword"),title:r.Ay.translate("ButtonForgotPassword")})}function o(e){e.querySelector("form").addEventListener("submit",(function(t){return ApiClient.ajax({type:"POST",url:ApiClient.getUrl("Users/ForgotPassword"),dataType:"json",contentType:"application/json",data:JSON.stringify({EnteredUsername:e.querySelector("#txtName").value})}).then(s),t.preventDefault(),!1}))}}}]);